*!
*! create_OSHPD03data_111212.do 
*!
*!  
*!  Cleans up patient discharge data:
*!    - drops unnecessary variables
*!    - adds patient diagnoses as defined in Ho (2006)
*!    - labels values appropriately
*! 	  - keeps only privately insured patients
*!    - creates 2 datasets: number of patients by diagnosis-age-gender-zip and number patients by oshpdid-diagnosis-zip
*!
*!  
*!

set mem 2000m
log using create_OSHPD03data_111212.txt, text replace
use pdd2003.dta, clear

count

//Keep only privately insured
tab pay_cat					//01 is Medicare, 02 Medical, 03 Private
keep if pay_cat==3

// Get rid of stragglers from previous years
drop if admtyr != 2003

// Drop variables wihout mercy
drop admtyr

drop if strmatch(patzip, "YYYYY")    // outside US
drop if strmatch(patzip, "ZZZZZ")    // homeless
drop if strmatch(patzip, "XXXXX")    // unknown

// drop partly-masked zips (very few of them)
drop if regexm(patzip, "[0-9][0-9][0-9]00")
drop if patzip=="*"
count

//Drop obs w/N.A.
tab agecat
drop if agecat==0
count

tab sex			//1 male 2 female 3 other 4 unknown
drop if sex==.
drop if sex==3 | sex==4
count

// Convert variables to numbers
rename oshpd_id oshpdid
destring patzip, replace

// Code the diagnostic group according to Ho 2006 pg 71 table VIII
gen tmpdiag = substr(diag_p, 1, 3)
gen diagnosis="na"

//First deal with the newborn baby diagnosis since that requires tmpdiag to be a string
replace diagnosis="newborn" if tmpdiag=="V29" | tmpdiag=="V30" | tmpdiag=="V31" | tmpdiag=="V32" | tmpdiag=="V33" | tmpdiag=="V34" | tmpdiag=="V35" | tmpdiag=="V36" | tmpdiag=="V37" | tmpdiag=="V38" | tmpdiag=="V39"

//Then destring and generate other diagnoses
destring tmpdiag, ignore("V") replace

replace diagnosis="cardiac" if tmpdiag >=393 & tmpdiag <=398
replace diagnosis="cardiac" if tmpdiag >=401 & tmpdiag <=405
replace diagnosis="cardiac" if tmpdiag >=410 & tmpdiag <=417
replace diagnosis="cardiac" if tmpdiag >=420 & tmpdiag <=429

replace diagnosis="cancer" if tmpdiag >=140 & tmpdiag <=239
replace diagnosis="digestive" if tmpdiag >=520 & tmpdiag <=579

replace diagnosis="neurological" if tmpdiag >=320 & tmpdiag <=326
replace diagnosis="neurological" if tmpdiag >=330 & tmpdiag <=337
replace diagnosis="neurological" if tmpdiag >=340 & tmpdiag <=359

replace diagnosis="labor" if tmpdiag >=650 & tmpdiag <=677
replace diagnosis="labor" if tmpdiag==644 | tmpdiag==647 | tmpdiag==648 | tmpdiag==27
replace diagnosis="labor" if tmpdiag >=22 & tmpdiag <=24
replace diagnosis="labor" if tmpdiag >=640 & tmpdiag <=648
replace diagnosis="labor" if tmpdiag >=630 & tmpdiag <=633
replace diagnosis="labor" if tmpdiag >=634 & tmpdiag <=639

replace diagnosis="othercode" if diagnosis=="na" & tmpdiag > 0 & tmpdiag <.
replace diagnosis="none" if diagnosis=="na" & tmpdiag < 0

tab diagnosis

drop tmpdiag 
label variable diagnosis "Diagnostic category as per Ho 2006"

// code age as in Ho (2006)
gen agecat_Ho=0
replace agecat_Ho = 1 if agecat<6
replace agecat_Ho = 2 if agecat>5 & agecat<9
replace agecat_Ho = 3 if agecat>8 & agecat<11
replace agecat_Ho = 4 if agecat>10 & agecat<13
replace agecat_Ho = 5 if agecat>12 & agecat<15
replace agecat_Ho = 6 if agecat>14

tab agecat_Ho
label variable agecat_Ho "1=0-19, 2=18-34, 3=35-44, 4=45-54, 5=55-64, 6=>=65"

keep oshpdid agecat_Ho diagnosis sex patzip pay_cat pay_typ pay_plan diag_p
sum
tab pay_cat   //03 is private
tab pay_type  //1 is Knox Keene, 2 is Mged Care-Other, 3 is Traditional, 4 is other
tab sex      //1 is male, 2 female
tab agecat_Ho
tab diagnosis
save oshpd03_subset.dta, replace

//Create dataset with number of patients by zip-age-sex-diagnosis
gen num=1
collapse (sum) num, by(agecat_Ho sex patzip diagnosis)
rename num numpats
label variable agecat_Ho "1=0-19, 2=18-34, 3=35-44, 4=45-54, 5=55-64, 6=>=65"
label variable sex "1=male, 2=female"
label variable patzip "5 digit zip from oshpd 2003 discharge data. Some outside CA"
label variable diagnosis "diagnosis category from diag_p, using defns in Ho (2006) table V111"
save oshpd03_zipagesexdiag.dta, replace
sum
clear

//Create dataset with number of patietns by oshpdid-zip-diagnosis
use oshpd03_subset.dta
gen num=1
collapse (sum) num, by(oshpdid patzip diagnosis)
rename num numpats
label variable patzip "5 digit zip from oshpd 2003 discharge data. Some outside CA"
label variable diagnosis "diagnosis category from diag_p, using defns in Ho (2006) table V111"
save oshpd03_hospzipdiag.dta, replace
sum
clear

log close



